% simple example of solving an ode with ode45

clear; close all; clc;

NumInitialConditions = 20;

for i = 1:NumInitialConditions
    
    figure(1);
    %% change these limits if you want the phase portrait over a bigger or smaller range of x and y
    xlim([-1 +1]); ylim([-1 +1]); % chan
    
    %% % input by clicking on a plot
    if i ==1 
        title({'click anywhere inside the plot to provide an initial condition','click on a few points to make a full phase portrait'})
    else
        title({'click anywhere inside the plot to provide an initial condition','click on a few points to make a full phase portrait','blue is forward in time, red is backward in time from the clicked point'})
    end
    stateVar0 = ginput(1); % we draw a phase trajectory starting from this initial point
    
    %% integration forward in time
    % time span for forward integration
    tspan = linspace(0,20,1000)';
    % if these tolerances are low, the solution is more accurate
    options = odeset('reltol',1e-9,'abstol',1e-9);
    % using ode45
    [~,stateVarlist] = ode45(@fRHS_ode,tspan,stateVar0,options);
    
    % plot the phase trajectory forward from the clicked point
    x1List = stateVarlist(:,1);
    x2List = stateVarlist(:,2);
    figure(1); hold on;
    plot(x1List,x2List,'b');
    axis equal;
    xlim([-1 1]); ylim([-1 +1]);
    
    %% integration backward in time
    % time span for forward integration
    tspan = linspace(0,-20,1000)';
    % if these tolerances are low, the solution is more accurate
    options = odeset('reltol',1e-9,'abstol',1e-9);
    % using ode45
    [~,stateVarlist] = ode45(@fRHS_ode,tspan,stateVar0,options);
    
    % plot the phase trajectory forward from the clicked point
    x1List = stateVarlist(:,1);
    x2List = stateVarlist(:,2);
    figure(1); hold on;
    plot(x1List,x2List,'r');
    axis equal;
    xlim([-1 1]); ylim([-1 +1]);
    xlabel('x1'); ylabel('x2');


end


